@@ -127,10 +127,15 @@ int stat PARAMS((const char *__path, struct stat *__statbuf));
 #define MODE_RWX	(S_IXUSR | S_IXGRP | S_IXOTH | MODE_RW)
 #define MODE_ALL	(S_ISUID | S_ISGID | S_ISVTX | MODE_RWX)
 
+#if 1
+#include <stdbool.h>
+typedef bool boolean;
+#else
 /* Not char because of type promotion; NeXT gcc can't handle it.  */
 typedef int boolean;
 #define		true    1
 #define		false	0
+#endif
 
 /* Pointer to function returning boolean. */
 typedef boolean (*PFB)();
@@ -414,6 +419,7 @@ extern time_t cur_day_start;
 extern boolean full_days;
 extern boolean no_leaf_check;
 extern boolean stay_on_filesystem;
+extern boolean ignore_readdir_race;
 extern boolean stop_at_current_level;
 extern boolean have_stat;
 extern char *rel_pathname;
