@@ -79,7 +79,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../../findutils/intl/plural.y"
+#line 1 "../../findutils.newgnulib/intl/plural.y"
 
 /* Expression parsing for plural form selection.
    Copyright (C) 2000, 2001 Free Software Foundation, Inc.
@@ -148,7 +148,7 @@
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 57 "../../findutils/intl/plural.y"
+#line 57 "../../findutils.newgnulib/intl/plural.y"
 typedef union YYSTYPE {
   unsigned long int num;
   enum operator op;
@@ -164,7 +164,7 @@ typedef union YYSTYPE {
 
 
 /* Copy the second part of user declarations.  */
-#line 63 "../../findutils/intl/plural.y"
+#line 63 "../../findutils.newgnulib/intl/plural.y"
 
 /* Prototypes for local functions.  */
 static struct expression *new_exp PARAMS ((int nargs, enum operator op,
@@ -1150,7 +1150,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 183 "../../findutils/intl/plural.y"
+#line 183 "../../findutils.newgnulib/intl/plural.y"
     {
 	    if (yyvsp[0].exp == NULL)
 	      YYABORT;
@@ -1159,70 +1159,70 @@ yyreduce:
     break;
 
   case 3:
-#line 191 "../../findutils/intl/plural.y"
+#line 191 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_3 (qmop, yyvsp[-4].exp, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 4:
-#line 195 "../../findutils/intl/plural.y"
+#line 195 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (lor, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 5:
-#line 199 "../../findutils/intl/plural.y"
+#line 199 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (land, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 6:
-#line 203 "../../findutils/intl/plural.y"
+#line 203 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 7:
-#line 207 "../../findutils/intl/plural.y"
+#line 207 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 8:
-#line 211 "../../findutils/intl/plural.y"
+#line 211 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 9:
-#line 215 "../../findutils/intl/plural.y"
+#line 215 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 10:
-#line 219 "../../findutils/intl/plural.y"
+#line 219 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_1 (lnot, yyvsp[0].exp);
 	  }
     break;
 
   case 11:
-#line 223 "../../findutils/intl/plural.y"
+#line 223 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = new_exp_0 (var);
 	  }
     break;
 
   case 12:
-#line 227 "../../findutils/intl/plural.y"
+#line 227 "../../findutils.newgnulib/intl/plural.y"
     {
 	    if ((yyval.exp = new_exp_0 (num)) != NULL)
 	      yyval.exp->val.num = yyvsp[0].num;
@@ -1230,7 +1230,7 @@ yyreduce:
     break;
 
   case 13:
-#line 232 "../../findutils/intl/plural.y"
+#line 232 "../../findutils.newgnulib/intl/plural.y"
     {
 	    yyval.exp = yyvsp[-1].exp;
 	  }
@@ -1434,7 +1434,7 @@ yyreturn:
 }
 
 
-#line 237 "../../findutils/intl/plural.y"
+#line 237 "../../findutils.newgnulib/intl/plural.y"
 
 
 void
