@@ -1,5 +1,5 @@
 /* xargs -- build and execute command lines from standard input
-   Copyright (C) 1990, 91, 92, 93, 94, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 2000,2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -62,6 +62,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <getopt.h>
+#include <fcntl.h>
 
 #if defined(HAVE_STRING_H) || defined(STDC_HEADERS)
 #include <string.h>
@@ -140,6 +141,28 @@ extern int errno;
 
 extern char **environ;
 
+/* Do multibyte processing if multibyte characters are supported,
+   unless multibyte sequences are search safe.  Multibyte sequences
+   are search safe if searching for a substring using the byte
+   comparison function 'strstr' gives no false positives.  All 8-bit
+   encodings and the UTF-8 multibyte encoding are search safe, but
+   the EUC encodings are not.
+   BeOS uses the UTF-8 encoding exclusively, so it is search safe. */
+#if defined __BEOS__
+# define MULTIBYTE_IS_SEARCH_SAFE 1
+#endif
+#define DO_MULTIBYTE (HAVE_MBLEN && ! MULTIBYTE_IS_SEARCH_SAFE)
+
+#if DO_MULTIBYTE
+# if HAVE_MBRLEN
+#  include <wchar.h>
+# else
+   /* Simulate mbrlen with mblen as best we can.  */
+#  define mbstate_t int
+#  define mbrlen(s, n, ps) mblen (s, n)
+# endif
+#endif
+
 /* Not char because of type promotion; NeXT gcc can't handle it.  */
 typedef int boolean;
 #define		true    1
@@ -263,6 +286,7 @@ static struct option const longopts[] =
 
 static int read_line PARAMS ((void));
 static int read_string PARAMS ((void));
+static char *mbstrstr PARAMS ((const char *haystack, const char *needle));
 static void do_insert PARAMS ((char *arg, size_t arglen, size_t lblen));
 static void push_arg PARAMS ((char *arg, size_t len));
 static boolean print_args PARAMS ((boolean ask));
@@ -279,6 +303,8 @@ main (int argc, char **argv)
   int optc;
   int always_run_command = 1;
   long orig_arg_max;
+  long arg_size;
+  long size_of_environment = env_size(environ);
   char *default_cmd = "/bin/echo";
   int (*read_args) PARAMS ((void)) = read_line;
 
@@ -296,12 +322,8 @@ main (int argc, char **argv)
   orig_arg_max -= 2048; /* POSIX.2 requires subtracting 2048.  */
   arg_max = orig_arg_max;
 
-  /* Sanity check for systems with huge ARG_MAX defines (e.g., Suns which
-     have it at 1 meg).  Things will work fine with a large ARG_MAX but it
-     will probably hurt the system more than it needs to; an array of this
-     size is allocated.  */
-  if (arg_max > 20 * 1024)
-    arg_max = 20 * 1024;
+  arg_size = 20 * 1048 + size_of_environment;
+  
 
   /* Take the size of the environment into account.  */
   arg_max -= env_size (environ);
@@ -351,11 +373,15 @@ main (int argc, char **argv)
 	  args_per_exec = parse_num (optarg, 'n', 1L, -1L);
 	  /* -n excludes -i -l.  */
 	  lines_per_exec = 0;
-	  replace_pat = NULL;
+	  if (args_per_exec == 1 && replace_pat)
+	    /* ignore -n1 in '-i -n1' */
+	    args_per_exec = 0;
+	  else
+	    replace_pat = NULL;
 	  break;
 
 	case 's':
-	  arg_max = parse_num (optarg, 's', 1L, orig_arg_max);
+	  arg_size = parse_num (optarg, 's', 1L, orig_arg_max);
 	  break;
 
 	case 't':
@@ -398,6 +424,17 @@ main (int argc, char **argv)
       argv = &default_cmd;
     }
 
+  /* Taking into account the sisze of the environment, 
+   * figure out how large a buffer we need to
+   * hold all the arguments.  We cannot use ARG_MAX 
+   * directly since that may be arbitrarily large.
+   * This is from a patch by Bob Prolux, <bob@proulx.com>.
+   */
+  if (arg_max > arg_size)
+    {
+      arg_max = arg_size;
+    }
+  
   linebuf = (char *) xmalloc (arg_max + 1);
   argbuf = (char *) xmalloc (arg_max + 1);
 
@@ -449,6 +486,61 @@ main (int argc, char **argv)
   exit (child_error);
 }
 
+#if 0
+static int
+append_char_to_buf(char **pbuf, char **pend, char **pp, int c)
+{
+  char *end_of_buffer = *pend;
+  char *start_of_buffer = *pbuf;
+  char *p = *pp;
+  if (p >= end_of_buffer)
+    {
+      if (replace_pat)
+	{
+	  size_t len = end_of_buffer - start_of_buffer;
+	  size_t offset = p - start_of_buffer;
+	  len *= 2;
+	  start_of_buffer = xrealloc(start_of_buffer, len*2);
+	  if (NULL != start_of_buffer)
+	    {
+	      end_of_buffer = start_of_buffer + len;
+	      p = start_of_buffer + offset;
+	      *p++ = c;
+
+	      /* Update the caller's idea of where the buffer is. */
+	      *pbuf = start_of_buffer;
+	      *pend = end_of_buffer;
+	      *pp = p;
+	      
+	      return 0;
+	    }
+	  else
+	    {
+	      /* Failed to reallocate. */
+	      return -1;
+	    }
+	}
+      else
+	{
+	  /* I suspect that this can never happen now, because append_char_to_buf()
+	   * should only be called wen replace_pat is true.
+	   */
+	  error (1, 0, _("argument line too long"));
+	  /*NOTREACHED*/
+	  return -1;
+	}
+    }
+  else
+    {
+      /* Enough space remains. */
+      *p++ = c;
+      *pp = p;
+      return 0;
+    }
+}
+#endif
+
+
 /* Read a line of arguments from stdin and add them to the list of
    arguments to pass to the command.  Ignore blank lines and initial blanks.
    Single and double quotes and backslashes quote metacharacters and blanks
@@ -567,9 +659,13 @@ read_line (void)
 	  state = NORM;
 	  break;
 	}
+#if 1
       if (p >= endbuf)
 	error (1, 0, _("argument line too long"));
       *p++ = c;
+#else
+      append_char_to_buf(&linebuf, &endbuf, &p, c);
+#endif
     }
 }
 
@@ -618,6 +714,37 @@ read_string (void)
     }
 }
 
+/* Finds the first occurrence of the substring NEEDLE in the string
+   HAYSTACK.  Both strings can be multibyte strings.  */
+
+static char *
+mbstrstr (const char *haystack, const char *needle)
+{
+#if DO_MULTIBYTE
+  if (MB_CUR_MAX > 1)
+    {
+      size_t hlen = strlen (haystack);
+      size_t nlen = strlen (needle);
+      mbstate_t mbstate;
+      size_t step;
+
+      memset (&mbstate, 0, sizeof (mbstate_t));
+      while (hlen >= nlen)
+	{
+	  if (memcmp (haystack, needle, nlen) == 0)
+	    return (char *) haystack;
+	  step = mbrlen (haystack, hlen, &mbstate);
+	  if (step <= 0)
+	    break;
+	  haystack += step;
+	  hlen -= step;
+	}
+      return NULL;
+    }
+#endif
+  return strstr (haystack, needle);
+}
+
 /* Replace all instances of `replace_pat' in ARG with `linebuf',
    and add the resulting string to the list of arguments for the command
    to execute.
@@ -644,7 +771,7 @@ do_insert (char *arg, size_t arglen, size_t lblen)
   do
     {
       size_t len;		/* Length in ARG before `replace_pat'.  */
-      char *s = strstr (arg, replace_pat);
+      char *s = mbstrstr (arg, replace_pat);
       if (s)
 	len = s - arg;
       else
@@ -690,6 +817,7 @@ push_arg (char *arg, size_t len)
 	{
 	  if (initial_args || cmd_argc == initial_argc)
 	    error (1, 0, _("can not fit single argument within argument list size limit"));
+	  /* option -i (replace_pat) implies -x (exit_if_size_exceeded) */
 	  if (replace_pat
 	      || (exit_if_size_exceeded &&
 		  (lines_per_exec || args_per_exec)))
@@ -763,6 +891,29 @@ print_args (boolean ask)
   return false;
 }
 
+
+/* Close stdin and attach /dev/null to it.
+ * This resolves Savannah bug #3992.
+ */
+static void
+prep_child_for_exec (void)
+{
+  const char inputfile[] = "/dev/null";
+  /* fprintf(stderr, "attaching stdin to /dev/null\n"); */
+  
+  close(0);
+  if (open(inputfile, O_RDONLY) < 0)
+    {
+      /* This is not entirely fatal, since 
+       * executing the child with a closed
+       * stdin is almost as good as executing it
+       * with its stdin attached to /dev/null.
+       */
+      error (0, errno, "%s", inputfile);
+    }
+}
+
+
 /* Execute the command that has been built in `cmd_argv'.  This may involve
    waiting for processes that were previously executed.  */
 
@@ -788,6 +939,7 @@ do_exec (void)
 	  error (1, errno, _("cannot fork"));
 
 	case 0:		/* Child.  */
+	  prep_child_for_exec();
 	  execvp (cmd_argv[0], cmd_argv);
 	  error (0, errno, "%s", cmd_argv[0]);
 	  _exit (errno == ENOENT ? 127 : 126);
@@ -933,6 +1085,6 @@ Usage: %s [-0prtx] [-e[eof-str]] [-i[replace-str]] [-l[max-lines]]\n\
        [--max-args=max-args] [--no-run-if-empty] [--version] [--help]\n\
        [command [initial-arguments]]\n"),
 	   program_name);
-  fputs (_("\nReport bugs to <bug-findutils@gnu.org>."), stream);
+  fputs (_("\nReport bugs to <bug-findutils@gnu.org>.\n"), stream);
   exit (status);
 }
